@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/../spec_helper'
+require 'spec_helper'
 
 class WorkingDuck
   # The WorkingDuck Class should work as a Backend
@@ -91,4 +91,4 @@ describe "OEmbed::Formatter::XML::Backends::DuckType" do
     }.to raise_error(LoadError)
     expect(OEmbed::Formatter::XML.backend).to_not be(instance)
   end
-end
\ No newline at end of file
+end
