@@ -1,9 +1,9 @@
-require File.dirname(__FILE__) + '/../../spec_helper'
+require 'spec_helper'
 
 describe "OEmbed::Formatter::JSON::Backends::Yaml" do
   include OEmbedSpecHelper
 
-  before(:all) do
+  before(:each) do
     expect {
       OEmbed::Formatter::JSON.backend = 'Yaml'
     }.to_not raise_error
@@ -52,4 +52,4 @@ describe "OEmbed::Formatter::JSON::Backends::Yaml" do
       decode = OEmbed::Formatter.decode(:json, valid_response(:json))
     }.to raise_error(OEmbed::ParseError)
   end
-end
\ No newline at end of file
+end
