@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/../../spec_helper'
+require 'spec_helper'
 
 describe "OEmbed::Formatter::XML::Backends::Nokogiri" do
   include OEmbedSpecHelper
@@ -9,7 +9,9 @@ describe "OEmbed::Formatter::XML::Backends::Nokogiri" do
     }.to raise_error(LoadError)
 
     require 'nokogiri'
+  end
 
+  before(:each) do
     expect {
       OEmbed::Formatter::XML.backend = 'Nokogiri'
     }.to_not raise_error
@@ -56,4 +58,4 @@ describe "OEmbed::Formatter::XML::Backends::Nokogiri" do
       decode = OEmbed::Formatter.decode(:xml, valid_response(:xml))
     }.to raise_error(OEmbed::ParseError)
   end
-end
\ No newline at end of file
+end
