@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 
 describe OEmbed::Formatter do
   include OEmbedSpecHelper
@@ -34,4 +34,4 @@ describe OEmbed::Formatter do
     expect(decoded.keys).to eq(valid_response(:object).keys)
     expect(decoded.values.map{|v|v.to_s}).to eq(valid_response(:object).values.map{|v|v.to_s})
   end
-end
\ No newline at end of file
+end
