@@ -1,15 +1,18 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 require 'json'
 
 describe OEmbed::ProviderDiscovery do
   before(:all) do
-    OEmbed::Formatter::JSON.backend = 'JSONGem'
     VCR.insert_cassette('OEmbed_ProviderDiscovery')
   end
   after(:all) do
     VCR.eject_cassette
   end
 
+  before(:each) do
+    OEmbed::Formatter::JSON.backend = 'JSONGem'
+  end
+
   include OEmbedSpecHelper
 
   {
@@ -20,17 +23,12 @@ describe OEmbed::ProviderDiscovery do
     # ]
     'youtube' => [
       'http://www.youtube.com/watch?v=u6XAPnuFjJc',
-      {:json=>'http://www.youtube.com/oembed', :xml=>'http://www.youtube.com/oembed'},
+      {:json=>'https://www.youtube.com/oembed', :xml=>'https://www.youtube.com/oembed'},
       :json,
     ],
     'vimeo' => [
-      'http://vimeo.com/27953845',
-      {:json=>'http://vimeo.com/api/oembed.json', :xml=>'http://vimeo.com/api/oembed.xml'},
-      :json,
-    ],
-    'facebook-photo' => [
-      'https://www.facebook.com/Federer/photos/pb.64760994940.-2207520000.1456668968./10153235368269941/?type=3&theater',
-      'https://www.facebook.com/plugins/post/oembed.json/',
+      'https://vimeo.com/27953845',
+      {:json=>'https://vimeo.com/api/oembed.json', :xml=>'https://vimeo.com/api/oembed.xml'},
       :json,
     ],
     'tumblr' => [
@@ -38,11 +36,6 @@ describe OEmbed::ProviderDiscovery do
       'https://www.tumblr.com/oembed/1.0',
       :json
     ],
-    'noteflight' => [
-      'http://www.noteflight.com/scores/view/09665392c94475f65dfaf5f30aadb6ed0921939d',
-      {:json=>'http://www.noteflight.com/services/oembed', :xml=>'http://www.noteflight.com/services/oembed'},
-      :json,
-    ],
     # TODO: Enhance ProviderDiscovery to support arbitrary query parameters. See https://github.com/ruby-oembed/ruby-oembed/issues/15
     #'wordpress' => [
     #  'http://sweetandweak.wordpress.com/2011/09/23/nothing-starts-the-morning-like-a-good-dose-of-panic/',
